/*== R&S RSC Attenuator Controller Include File =============================*/
/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSRSC_HEADER
#define __RSRSC_HEADER

#include <visa.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8               (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                  (_VI_ERROR+0x3FFC0900L)

#define RSRSC_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
/* Add instrument driver specific error codes here */

#define RSRSC_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSRSC_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSRSC_ERROR_INSTRUMENT_NSUP_MODEL      (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSRSC_ERROR_SETTINGS_CONFLICT          (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSRSC_ERROR_CALIBRATION_FAILED         (VI_ERROR_INSTR_OFFSET + 0xF5L)
/* Add instrument driver specific warning codes here */
#define RSRSC_WARNING_SMALL_BUFFER             (VI_WARNING_INSTR_OFFSET + 0xF1L)
#define RSRSC_WARNING_NOT_SUPPORTED            (VI_WARNING_INSTR_OFFSET + 0xF2L)

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/

#define RSRSC_ATTENUATOR_INTERNAL 	1
#define RSRSC_ATTENUATOR_EXT_1    	2
#define RSRSC_ATTENUATOR_EXT_2    	3
#define RSRSC_ATTENUATOR_EXT_3    	4
#define RSRSC_ATTENUATOR_EXT_4    	5
#define RSRSC_ATTENUATOR_LOG_1    	6
#define RSRSC_ATTENUATOR_LOG_2    	7
	
#define RSRSC_USER_CALIBRATION_OFF    	0
#define RSRSC_USER_CALIBRATION_OFFSET 	1
#define RSRSC_USER_CALIBRATION_A      	2
#define RSRSC_USER_CALIBRATION_FULL   	3

#define RSRSC_CORR_MODE_REL  0
#define RSRSC_CORR_MODE_ABS  1

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rsrsc_Initialize (ViRsrc resourceName, ViBoolean IDQuery,
                                    ViBoolean resetDevice,
                                    ViPSession instrumentHandle);
ViStatus _VI_FUNC rsrsc_ConfigureAttenuation (ViSession instrumentHandle,
                                              ViInt32 attenuator,
                                              ViReal64 attenuation);
ViStatus _VI_FUNC rsrsc_ConfigureAttenuatorCascading (ViSession instrumentHandle,
                                                      ViInt32 attenuator,
                                                      ViBoolean status,
                                                      ViString attenuators);
ViStatus _VI_FUNC rsrsc_ConfigureCorrectionMode (ViSession instrumentHandle,
                                                 ViInt32 attenuator,
                                                 ViBoolean correctionMode);
ViStatus _VI_FUNC rsrsc_ConfigureFrequency (ViSession instrumentHandle,
                                            ViInt32 attenuator, ViReal64 frequency);
ViStatus _VI_FUNC rsrsc_ConfigureUserCalibration (ViSession instrumentHandle,
                                                  ViInt32 attenuator,
                                                  ViInt32 correctionMode,
                                                  ViInt32 userCalibration,
                                                  ViReal64 offset);
ViStatus _VI_FUNC rsrsc_ConfigureSystemDate (ViSession instrumentHandle,
                                             ViInt32 year, ViInt32 month,
                                             ViInt32 day);
ViStatus _VI_FUNC rsrsc_ConfigureSystemTime (ViSession instrumentHandle,
                                             ViInt32 hour, ViInt32 minute,
                                             ViInt32 second);
ViStatus _VI_FUNC rsrsc_QueryAttenuatorDeviation (ViSession instrumentHandle,
                                                  ViInt32 attenuator,
                                                  ViPReal64 deviation);
ViStatus _VI_FUNC rsrsc_QueryAttenuatorList (ViSession instrumentHandle,
                                             ViInt32 bufferSize,
                                             ViChar _VI_FAR attenuatorList[]);
ViStatus _VI_FUNC rsrsc_QueryAttenuatorName (ViSession instrumentHandle,
                                             ViInt32 attenuator, ViInt32 bufferSize,
                                             ViChar _VI_FAR attenuatorName[]);
ViStatus _VI_FUNC rsrsc_QueryAttenuatorCatalogList (ViSession instrumentHandle,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR attenuatorCatalogList[]);
ViStatus _VI_FUNC rsrsc_LoadCorrectionDataFile (ViSession instrumentHandle,
                                                ViInt32 attenuator,
                                                ViString fileName);
ViStatus _VI_FUNC rsrsc_QueryHardwareInformation (ViSession instrumentHandle,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR hardwareInformation[]);
ViStatus _VI_FUNC rsrsc_QuerySoftwareInformation (ViSession instrumentHandle,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR softwareInformation[]);
ViStatus _VI_FUNC rsrsc_errorCheckState (ViSession instrumentHandle,
                                         ViBoolean stateChecking);
ViStatus _VI_FUNC rsrsc_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rsrsc_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsrsc_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrsc_SelfTest (ViSession instrumentHandle,
                                  ViPInt16 selfTestResult,
                                  ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsrsc_ErrorQuery (ViSession instrumentHandle, ViPInt32 errorCode,
                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsrsc_ErrorMessage (ViSession instrumentHandle,
                                      ViStatus statusCode,
                                      ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsrsc_RevisionQuery (ViSession instrumentHandle,
                                       ViChar _VI_FAR instrumentDriverRevision[],
                                       ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsrsc_ReadAllSystemMessages (ViSession instrumentHandle,
                                               ViInt32 bufferSize,
                                               ViChar _VI_FAR systemMessages[]);
ViStatus _VI_FUNC rsrsc_ClearAllSystemMessages (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrsc_Close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif

